@@ -1,6 +1,5 @@
 import sys, os
 import vtkmodules
-from vtkmodules.vtkCommonCore import vtkVersion
 
 def vtkLoadPythonTkWidgets(interp):
     """vtkLoadPythonTkWidgets(interp) -- load vtk-tk widget extensions
@@ -10,16 +9,7 @@ def vtkLoadPythonTkWidgets(interp):
     the python path and the tcl path are searched.
     """
     modname = 'vtkRenderingTk'
-    VTK_VERSIONED_INSTALL = "OFF"
-    VTK_CUSTOM_LIBRARY_VERSION = ""
-    if VTK_VERSIONED_INSTALL in ("0", "OFF", "NO", "FALSE", "N"):
-        name = modname
-    elif VTK_CUSTOM_LIBRARY_VERSION:
-        name = '%s-%s' % (modname,VTK_CUSTOM_LIBRARY_VERSION)
-    else:
-        X = vtkVersion.GetVTKMajorVersion()
-        Y = vtkVersion.GetVTKMinorVersion()
-        name = '%s-%d.%d' % (modname,X,Y)
+    name = 'vtkRenderingTk'
     pkgname = modname.lower().capitalize()
 
     # find out if the module is already loaded
@@ -57,6 +47,11 @@ def vtkLoadPythonTkWidgets(interp):
             if os.path.basename(lib_dir).startswith('lib'):
                 pathlist.append(lib_dir)
 
+    # a likely relative path for windows wheel
+    if sys.platform == 'win32':
+        package_dir = os.path.dirname(vtkmodules_dir)
+        pathlist.append(os.path.join(package_dir, "vtk.libs"))
+
     # add tcl paths, ensure that {} is handled properly
     try:
         auto_paths = interp.getvar('auto_path').split()
@@ -92,9 +87,7 @@ def vtkLoadPythonTkWidgets(interp):
             fullpath = os.path.join(path, filename)
         except AttributeError:
             pass
-        if ' ' in fullpath:
-            fullpath = '{'+fullpath+'}'
-        if interp.eval('catch {load '+fullpath+' '+pkgname+'}') == '0':
+        if interp.eval('catch {load {'+fullpath+'} '+pkgname+'}') == '0':
             return
 
     # re-generate the error
